import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  scaleBand,
  extent,
  min,
  max,
  format,
  timeFormat,
  ticks
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { Title } from './Title';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = {
  top: 60,
  right: 30,
  bottom: 145,
  left: 90,
};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const title = 'Number of actions per month';
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 55;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
  console.log(data[0]);

  const xValue = (d) => d.month;
  const xAxisLabel = 'Month';

  const yValue = (d) => d.action;
  const yAxisLabel = 'Actions';

  const xAxisTickFormat = timeFormat('%Y');
  const numberFormat = (d) =>
    format('.2s')(d)
  		.replace(/^/, '$ ')
  		.replace(' ', '');

  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth]);

  const yScale = scaleLinear()
  	.domain([min(data, yValue)*0.9, max(data, yValue)])
    .range([innerHeight, 0])
 		.nice();

  return (
    <svg width={width} height={height}>
      <g
        className="tick"
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          tickFormat={xAxisTickFormat}
          xScale={xScale}
          innerHeight={innerHeight}
          tickOffset={20}
        />
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset={-25}
          axisFormat={numberFormat}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          textAnchor="middle"
          y={innerHeight + xAxisLabelOffset}
        >
          {/*xAxisLabel*/}
        </text>
        <text
          transform={`rotate(-90) translate(${
            -innerHeight / 2
          }, ${-yAxisLabelOffset})`}
          className="axis-label"
          text-anchor="middle"
        >
          {/*yAxisLabel*/}
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={6}
        />
        <Title chartTitle={title} innerWidth={innerWidth} />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
